/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is ServStats.
 *
 * The Initial Developer of the Original Code is
 * George J. Lee <gjl@csail.mit.edu>
 * Portions created by the Initial Developer are Copyright (C) 2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var diagTool;

//////////////////////
// DiagTool Object
function DiagTool() {};
DiagTool.prototype = {
  agent: null,
  debug: false,

  dump: function(aMessage) {
    if (this.debug) {
      var consoleService = Components.classes["@mozilla.org/consoleservice;1"].getService(Components.interfaces.nsIConsoleService);
      consoleService.logStringMessage("DiagTool: " + aMessage);
    }
  },

  start: function() {
    this.dump("Starting DiagTool");
    var prefs = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
    this.logging = prefs.getBoolPref("extensions.diagtool.logging");
    this.updateStatus();

    var observerService = Components.classes['@mozilla.org/observer-service;1'].getService(Components.interfaces.nsIObserverService);
    observerService.addObserver(this, "http-on-modify-request",   false);
    observerService.addObserver(this, "http-on-examine-response",   false);
    observerService.addObserver(this, 'StartDocumentLoad', false);
    observerService.addObserver(this, 'EndDocumentLoad', false);
    observerService.addObserver(this, 'FailDocumentLoad', false);
    observerService.addObserver(this, 'diagtool-pref-change', false);

    this.agent = Components.classes["@capri.csail.mit.edu/ua;1"].getService(Components.interfaces.nsIDiagAgent);

    gBrowser.addProgressListener(this.agent,
				 Components.interfaces.nsIWebProgress.NOTIFY_STATE_NETWORK |
				 Components.interfaces.nsIWebProgress.NOTIFY_STATE_DOCUMENT);

  },

  stop: function() {
    try {
      var observerService = Components.classes['@mozilla.org/observer-service;1'].getService(Components.interfaces.nsIObserverService);
      observerService.removeObserver(this, "http-on-modify-request");
      observerService.removeObserver(this, "http-on-examine-response");
      observerService.removeObserver(this, "StartDocumentLoad");
      observerService.removeObserver(this, "EndDocumentLoad");
      observerService.removeObserver(this, "FailDocumentLoad");
      observerService.removeObserver(this, "diagtool-pref-change");
      observerService = null;

      gBrowser.removeProgressListener(this.agent);
    } catch (e) {};
  },

  probeHosts: function() {
    hosts = ['localhost'];
    this.agent.probeHosts(hosts, hosts.length);
  },

  getHist: function() {
    return this.connHist;
  },

  activateButton: function() {
    var button = document.getElementById("diag-button");
    button.setAttribute("disabled", "false");
  },
  
  deactivateButton: function() {
    var button = document.getElementById("diag-button");
    button.setAttribute("disabled", "true");
  },
  
  observe: function(subject, topic, data) {
    switch (topic) {
      case "diagtool-pref-change":
        this.logging = (data == 'true');
        this.updateStatus();
        break;
      
      case "diagtool-failure":
        this.activateButton();
        break;
    }

  },

  updateStatus: function() {
    var active = document.getElementById("diag-popup-active");
    active.setAttribute("checked", this.logging);
  },

  toggleLogging: function(aEl, event) {
    var active = document.getElementById("diag-popup-active");
    this.logging = active.getAttribute("checked");

    var prefs = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
    prefs.setBoolPref("extensions.diagtool.logging", this.logging);
    
    var observerService = Components.classes['@mozilla.org/observer-service;1'].getService(Components.interfaces.nsIObserverService);
    observerService.notifyObservers(null, "diagtool-pref-change", this.logging)
  },

  openHistory: function() {
    window.openDialog('chrome://diag/content/history.xul', 'history', 'chrome,width=200,height=100');
  },

  openOptions: function() {
    window.openDialog('chrome://diag/content/options.xul', 'options', 'chrome');
  },

  requestDiagnosis: function() {
    this.dump("Requesting diagnosis");
    this.agent.requestDiagnosis("", false, true);
  },

  startLogging: function() {
    this.logging = true;
  },

  stopLogging: function() {
    this.logging = false;
  }
};

function dtLoad()
{
  diagTool = new DiagTool();
  diagTool.start();
};

function dtUnload()
{
  diagTool.stop();
  diagTool = null;
};

window.addEventListener("load", dtLoad, false);
window.addEventListener("unload", dtUnload, false);

